@@ -47,22 +47,50 @@ def rgb_24_get_is_dark(in_rgb_24):
     max_24 = 255
     return (r+g+b < max_24)
 
-def rgb_48_to_48_no_white(in_rgb_48):
-    r = int(in_rgb_48[:4], 16)
-    g = int(in_rgb_48[4:8], 16)
-    b = int(in_rgb_48[8:], 16)
-    # r+g+b black is 0
-    # r+g+b white is 3*65535 = 196605
-    max_48 = 65535
-    if r+g+b > 2.3*max_48:
-        r = max_48 - r
-        g = max_48 - g
-        b = max_48 - b
-        out_rgb_48 = "%.4x%.4x%.4x" % (r, g, b)
-        #print "%s to %s" % (in_rgb_48, out_rgb_48)
+def rgb_to_no_white(in_rgb):
+    if len(in_rgb) == 12:
+        r = int(in_rgb[:4], 16)
+        g = int(in_rgb[4:8], 16)
+        b = int(in_rgb[8:], 16)
+        # r+g+b black is 0
+        # r+g+b white is 3*65535
+        max_48 = 65535
+        if r+g+b > 2.3*max_48:
+            r = max_48 - r
+            g = max_48 - g
+            b = max_48 - b
+            out_rgb = "%.4x%.4x%.4x" % (r, g, b)
+            #print "%s to %s" % (in_rgb, out_rgb)
+        else:
+            out_rgb = in_rgb
     else:
-        out_rgb_48 = in_rgb_48
-    return out_rgb_48
+        if len(in_rgb) != 6:
+            in_rgb = rgb_any_to_24(in_rgb)
+        r = int(in_rgb[:2], 16)
+        g = int(in_rgb[2:4], 16)
+        b = int(in_rgb[4:], 16)
+        # r+g+b black is 0
+        # r+g+b white is 3*255
+        max_24 = 255
+        if r+g+b > 2.3*max_24:
+            r = max_24 - r
+            g = max_24 - g
+            b = max_24 - b
+            out_rgb = "%.2x%.2x%.2x" % (r, g, b)
+            #print "%s to %s" % (in_rgb, out_rgb)
+        else:
+            out_rgb = in_rgb
+    return out_rgb
+
+def clean_text_to_utf8(in_text):
+    """Clean from utf8 decode errors"""
+    clean_text = in_text
+    while clean_text:
+        try:
+            clean_text = unicode(clean_text, cons.STR_UTF8, cons.STR_IGNORE)
+            break
+        except: clean_text = clean_text[1:]
+    return clean_text
 
 class Export2CTD:
     """The Export to CTD Class"""
@@ -304,13 +332,14 @@ class Export2Txt:
     def get_table_plain(self, table_orig):
         """Returns the plain Table"""
         # table is: [offset, dict, justification]
-        table_plain = cons.CHAR_NEWLINE + self.dad.h_rule + cons.CHAR_NEWLINE + cons.CHAR_PIPE*2
+        table_plain = cons.CHAR_NEWLINE
         table = copy.deepcopy(table_orig)
         table[1]['matrix'].insert(0, table[1]['matrix'].pop())
         for j, row in enumerate(table[1]['matrix']):
+            table_plain += cons.CHAR_PIPE
             for cell in row:
-                table_plain += cons.CHAR_SPACE + cell + cons.CHAR_SPACE + cons.CHAR_PIPE*2
-            table_plain += cons.CHAR_NEWLINE + self.dad.h_rule + cons.CHAR_NEWLINE
+                table_plain += cons.CHAR_SPACE + cell + cons.CHAR_SPACE + cons.CHAR_PIPE
+            table_plain += cons.CHAR_NEWLINE
         return table_plain
 
     def plain_get_from_treestore_node(self, curr_buffer, sel_range, check_link_target):
@@ -341,17 +370,14 @@ class Export2Txt:
                 if curr_object[0] == "table": plain_text += self.get_table_plain(curr_object[1])
                 elif curr_object[0] == "codebox": plain_text += self.get_codebox_plain(curr_object[1])
         if tree_iter_for_node_name:
-            plain_text = self.plain_text_get_node_name(tree_iter_for_node_name) + plain_text
+            node_name = clean_text_to_utf8(self.dad.treestore[tree_iter_for_node_name][1])
+            plain_text = node_name.upper() + cons.CHAR_NEWLINE + plain_text
         if filepath:
             file_descriptor = open(filepath, 'a')
             file_descriptor.write(plain_text + 2*cons.CHAR_NEWLINE)
             file_descriptor.close()
         return plain_text
 
-    def plain_text_get_node_name(self, tree_iter):
-        """Get Node Name in Plain Text"""
-        return self.dad.treestore[tree_iter][1].upper() + cons.CHAR_NEWLINE
-
 class Export2Pango:
     """The Export to Pango Class"""
 
@@ -387,7 +413,7 @@ class Export2Pango:
                         former_tag_str = curr_tag_str
                         if span_opened: pango_text += "</span>"
                         # start of tag
-                        curr_tag_str = "#" + rgb_48_to_48_no_white(curr_tag_str[1:])
+                        curr_tag_str = "#" + rgb_to_no_white(curr_tag_str[1:])
                         pango_text += '<span foreground="%s" font_weight="%s">' % (curr_tag_str, font_weight)
                         span_opened = True
             elif span_opened:
@@ -482,7 +508,7 @@ class Export2Pango:
                     monospace_active = True
                     continue
                 elif tag_property == cons.TAG_FOREGROUND:
-                    property_value = "#" + rgb_48_to_48_no_white(property_value[1:])
+                    property_value = "#" + rgb_to_no_white(property_value[1:])
                 pango_attrs += ' %s="%s"' % (tag_property, property_value)
         if pango_attrs == '': tagged_text = cgi.escape(start_iter.get_text(end_iter))
         else: tagged_text = '<span' + pango_attrs + '>' + cgi.escape(start_iter.get_text(end_iter)) + '</span>'
@@ -560,20 +586,10 @@ class Export2Html:
             self.nodes_all_export_to_html_iter(child_tree_iter)
             child_tree_iter = self.dad.treestore.iter_next(child_tree_iter)
 
-    def clean_text_to_utf8(self, in_text):
-        """Clean from utf8 decode errors"""
-        clean_text = in_text
-        while clean_text:
-            try:
-                clean_text = unicode(clean_text, cons.STR_UTF8, cons.STR_IGNORE)
-                break
-            except: clean_text = clean_text[1:]
-        return clean_text
-
     def tree_links_text_iter(self, tree_iter):
         """Creating the Tree Links Text - iter"""
         href = self.get_html_filename(tree_iter)
-        node_name = self.clean_text_to_utf8(self.dad.treestore[tree_iter][1])
+        node_name = clean_text_to_utf8(self.dad.treestore[tree_iter][1])
         if self.tree_count_level < len(self.tree_links_nums):
             self.tree_count_level += 1
             self.tree_links_text += '<ol>\n'
@@ -609,13 +625,13 @@ class Export2Html:
             iter_start, iter_end = self.dad.curr_buffer.get_selection_bounds()
             sel_range = [iter_start.get_offset(), iter_end.get_offset()]
         else: sel_range = None
-        html_text = cons.HTML_HEADER % self.dad.treestore[tree_iter][1]
+        html_text = cons.HTML_HEADER % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
         if self.tree_links_text and self.dad.last_index_in_page:
             td_tree = r'<div class="main">'
             td_page = r'<div class="page">'
             html_text += td_tree + self.tree_links_text + td_page
             if self.dad.last_include_node_name:
-                html_text += '<h1><b><u>%s</u></b></h1>' % self.dad.treestore[tree_iter][1]
+                html_text += '<h1><b><u>%s</u></b></h1>' % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
         self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.RICH_TEXT_ID:
             text_n_objects = self.html_get_from_treestore_node(tree_iter, sel_range)
@@ -749,10 +765,10 @@ class Export2Html:
 
     def get_html_filename(self, tree_iter):
         """Get the HTML page filename given the tree iter"""
-        file_name = self.clean_text_to_utf8(self.dad.treestore[tree_iter][1]).strip()
+        file_name = clean_text_to_utf8(self.dad.treestore[tree_iter][1]).strip()
         father_iter = self.dad.treestore.iter_parent(tree_iter)
         while father_iter:
-            file_name = self.clean_text_to_utf8(self.dad.treestore[father_iter][1]).strip() + "--" + file_name
+            file_name = clean_text_to_utf8(self.dad.treestore[father_iter][1]).strip() + "--" + file_name
             father_iter = self.dad.treestore.iter_parent(father_iter)
         file_name = support.clean_from_chars_not_for_filename(file_name) + ".html"
         if len(file_name) > cons.MAX_FILE_NAME_LEN:
@@ -783,7 +799,7 @@ class Export2Html:
                         former_tag_str = curr_tag_str
                         if span_opened: html_text += "</span>"
                         # start of tag
-                        curr_tag_str = "#" + rgb_48_to_48_no_white(curr_tag_str[1:])
+                        curr_tag_str = "#" + rgb_to_no_white(curr_tag_str[1:])
                         html_text += '<span style="color:#%s;font-weight:%s">' % (rgb_any_to_24(curr_tag_str[1:]), font_weight)
                         span_opened = True
             elif span_opened:
@@ -892,7 +908,7 @@ class Export2Html:
                 elif tag_property == cons.TAG_FOREGROUND:
                     # color:#FFFF00
                     tag_property = "color"
-                    color_no_white = rgb_48_to_48_no_white(property_value[1:])
+                    color_no_white = rgb_to_no_white(property_value[1:])
                     property_value = "#" + rgb_any_to_24(color_no_white)
                 elif tag_property == cons.TAG_BACKGROUND:
                     # background-color:#FFFF00
