@@ -2,7 +2,7 @@
 #
 #       lists.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ class ListsHandler:
                             if not leading_num_count:
                                 leading_num_count = [[0, 1]]
                             else:
-                                leading_num_count = [[0, leading_num_count[0][1]]]
+                                leading_num_count = [[0, leading_num_count[0][1]+1]]
                         else:
                             level = list_info["level"]
                             index = level % cons.NUM_CHARS_LISTNUM
